@@ -566,42 +566,42 @@ class PqGetObjectsHelper {
     return ADBC_STATUS_OK;
   }
 
-  PGconn* conn_;
+  PGconn* conn_ = nullptr;
   int depth_;
-  const char* catalog_;
-  const char* db_schema_;
-  const char* table_name_;
-  const char** table_types_;
-  const char* column_name_;
-  struct ArrowSchema* schema_;
-  struct ArrowArray* array_;
-  struct AdbcError* error_;
+  const char* catalog_ = nullptr;
+  const char* db_schema_ = nullptr;
+  const char* table_name_ = nullptr;
+  const char** table_types_ = nullptr;
+  const char* column_name_ = nullptr;
+  struct ArrowSchema* schema_ = nullptr;
+  struct ArrowArray* array_ = nullptr;
+  struct AdbcError* error_ = nullptr;
   struct ArrowError na_error_;
-  struct ArrowArray* catalog_name_col_;
-  struct ArrowArray* catalog_db_schemas_col_;
-  struct ArrowArray* catalog_db_schemas_items_;
-  struct ArrowArray* db_schema_name_col_;
-  struct ArrowArray* db_schema_tables_col_;
-  struct ArrowArray* schema_table_items_;
-  struct ArrowArray* table_name_col_;
-  struct ArrowArray* table_type_col_;
-  struct ArrowArray* table_columns_col_;
-  struct ArrowArray* table_columns_items_;
-  struct ArrowArray* column_name_col_;
-  struct ArrowArray* column_position_col_;
-  struct ArrowArray* column_remarks_col_;
-  struct ArrowArray* table_constraints_col_;
-  struct ArrowArray* table_constraints_items_;
-  struct ArrowArray* constraint_name_col_;
-  struct ArrowArray* constraint_type_col_;
-  struct ArrowArray* constraint_column_names_col_;
-  struct ArrowArray* constraint_column_name_col_;
-  struct ArrowArray* constraint_column_usages_col_;
-  struct ArrowArray* constraint_column_usage_items_;
-  struct ArrowArray* fk_catalog_col_;
-  struct ArrowArray* fk_db_schema_col_;
-  struct ArrowArray* fk_table_col_;
-  struct ArrowArray* fk_column_name_col_;
+  struct ArrowArray* catalog_name_col_ = nullptr;
+  struct ArrowArray* catalog_db_schemas_col_ = nullptr;
+  struct ArrowArray* catalog_db_schemas_items_ = nullptr;
+  struct ArrowArray* db_schema_name_col_ = nullptr;
+  struct ArrowArray* db_schema_tables_col_ = nullptr;
+  struct ArrowArray* schema_table_items_ = nullptr;
+  struct ArrowArray* table_name_col_ = nullptr;
+  struct ArrowArray* table_type_col_ = nullptr;
+  struct ArrowArray* table_columns_col_ = nullptr;
+  struct ArrowArray* table_columns_items_ = nullptr;
+  struct ArrowArray* column_name_col_ = nullptr;
+  struct ArrowArray* column_position_col_ = nullptr;
+  struct ArrowArray* column_remarks_col_ = nullptr;
+  struct ArrowArray* table_constraints_col_ = nullptr;
+  struct ArrowArray* table_constraints_items_ = nullptr;
+  struct ArrowArray* constraint_name_col_ = nullptr;
+  struct ArrowArray* constraint_type_col_ = nullptr;
+  struct ArrowArray* constraint_column_names_col_ = nullptr;
+  struct ArrowArray* constraint_column_name_col_ = nullptr;
+  struct ArrowArray* constraint_column_usages_col_ = nullptr;
+  struct ArrowArray* constraint_column_usage_items_ = nullptr;
+  struct ArrowArray* fk_catalog_col_ = nullptr;
+  struct ArrowArray* fk_db_schema_col_ = nullptr;
+  struct ArrowArray* fk_table_col_ = nullptr;
+  struct ArrowArray* fk_column_name_col_ = nullptr;
 };
 
 // A notice processor that does nothing with notices. In the future we can log
